# moldenViz

[![PyPI - Version](https://img.shields.io/pypi/v/moldenviz.svg)](https://pypi.org/project/moldenviz)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/moldenviz.svg)](https://pypi.org/project/moldenviz)
[![Documentation Status](https://readthedocs.org/projects/moldenviz/badge/?version=latest)](https://moldenviz.readthedocs.io/en/latest/?badge=latest)

-----

## Installation

```console
pip install moldenViz
```

## Documentation
You can find the documentation [here](https://moldenviz.readthedocs.io/en/latest/).

## Usage

## Roadmap
- [x] 0.1: Basic commands inside python.
  - [x] 0.1.5: Documentation support
- [x] 0.2: Plotter.
- [ ] 0.3: CLI options.
